@@ -11,9 +11,9 @@ airds.coords["cell_area"] = (
     * 110e3
 )
 
-ds_no_attrs = airds.copy(deep=True)
-for variable in ds_no_attrs.variables:
-    ds_no_attrs[variable].attrs = {}
+ds_no_attrs = airds.copy(deep=False)
+for _variable in ds_no_attrs.variables:
+    ds_no_attrs[_variable].attrs = {}
 
 
 # POM dataset
@@ -154,62 +154,171 @@ romsds.coords["z_rho_dummy"] = (
 )
 
 
-# Dataset with random data on a grid that is some sort of Mollweide projection
-XX, YY = np.mgrid[:11, :11] * 5 - 25
-XX_bnds, YY_bnds = np.mgrid[:12, :12] * 5 - 27.5
+def _create_mollw_ds():
+    # Dataset with random data on a grid that is some sort of Mollweide projection
+    YY, XX = np.mgrid[:11, :11] * 5 - 25
+    YY_bnds, XX_bnds = np.mgrid[:12, :12] * 5 - 27.5
 
-R = 50
-theta = np.arcsin(YY / (R * np.sqrt(2)))
-lat = np.rad2deg(np.arcsin((2 * theta + np.sin(2 * theta)) / np.pi))
-lon = np.rad2deg(XX * np.pi / (R * 2 * np.sqrt(2) * np.cos(theta)))
+    R = 50
+    theta = np.arcsin(YY / (R * np.sqrt(2)))
+    lat = np.rad2deg(np.arcsin((2 * theta + np.sin(2 * theta)) / np.pi))
+    lon = np.rad2deg(XX * np.pi / (R * 2 * np.sqrt(2) * np.cos(theta)))
 
-theta_bnds = np.arcsin(YY_bnds / (R * np.sqrt(2)))
-lat_vertices = np.rad2deg(np.arcsin((2 * theta_bnds + np.sin(2 * theta_bnds)) / np.pi))
-lon_vertices = np.rad2deg(XX_bnds * np.pi / (R * 2 * np.sqrt(2) * np.cos(theta_bnds)))
+    theta_bnds = np.arcsin(YY_bnds / (R * np.sqrt(2)))
+    lat_vertices = np.rad2deg(
+        np.arcsin((2 * theta_bnds + np.sin(2 * theta_bnds)) / np.pi)
+    )
+    lon_vertices = np.rad2deg(
+        XX_bnds * np.pi / (R * 2 * np.sqrt(2) * np.cos(theta_bnds))
+    )
 
-lon_bounds = np.stack(
-    (
-        lon_vertices[:-1, :-1],
-        lon_vertices[:-1, 1:],
-        lon_vertices[1:, 1:],
-        lon_vertices[1:, :-1],
-    ),
-    axis=0,
-)
-lat_bounds = np.stack(
-    (
-        lat_vertices[:-1, :-1],
-        lat_vertices[:-1, 1:],
-        lat_vertices[1:, 1:],
-        lat_vertices[1:, :-1],
-    ),
-    axis=0,
-)
+    lon_bounds = np.stack(
+        (
+            lon_vertices[:-1, :-1],
+            lon_vertices[:-1, 1:],
+            lon_vertices[1:, 1:],
+            lon_vertices[1:, :-1],
+        ),
+        axis=-1,
+    )
+    lat_bounds = np.stack(
+        (
+            lat_vertices[:-1, :-1],
+            lat_vertices[:-1, 1:],
+            lat_vertices[1:, 1:],
+            lat_vertices[1:, :-1],
+        ),
+        axis=-1,
+    )
 
-mollwds = xr.Dataset(
-    coords=dict(
-        lon=xr.DataArray(
-            lon,
-            dims=("x", "y"),
-            attrs={"units": "degrees_east", "bounds": "lon_bounds"},
+    mollwds = xr.Dataset(
+        coords=dict(
+            lon=xr.DataArray(
+                lon,
+                dims=("y", "x"),
+                attrs={"units": "degrees_east", "bounds": "lon_bounds"},
+            ),
+            lat=xr.DataArray(
+                lat,
+                dims=("y", "x"),
+                attrs={"units": "degrees_north", "bounds": "lat_bounds"},
+            ),
         ),
-        lat=xr.DataArray(
-            lat,
-            dims=("x", "y"),
-            attrs={"units": "degrees_north", "bounds": "lat_bounds"},
+        data_vars=dict(
+            lon_bounds=xr.DataArray(
+                lon_bounds, dims=("y", "x", "bounds"), attrs={"units": "degrees_east"}
+            ),
+            lat_bounds=xr.DataArray(
+                lat_bounds, dims=("y", "x", "bounds"), attrs={"units": "degrees_north"}
+            ),
+            lon_vertices=xr.DataArray(lon_vertices, dims=("y_vertices", "x_vertices")),
+            lat_vertices=xr.DataArray(lat_vertices, dims=("y_vertices", "x_vertices")),
         ),
-    ),
-    data_vars=dict(
-        lon_bounds=xr.DataArray(
-            lon_bounds, dims=("bounds", "x", "y"), attrs={"units": "degrees_east"}
+    )
+
+    return mollwds
+
+
+mollwds = _create_mollw_ds()
+
+
+def _create_inexact_bounds():
+    # Dataset that creates rotated pole curvilinear coordinates with CF bounds in
+    # counterclockwise order that have precision issues.
+    lon = np.array(
+        [
+            [64.21746363939087, 64.42305921561967, 64.62774455060337],
+            [64.38488380781622, 64.5906340869802, 64.79546745916944],
+            [64.55349991538067, 64.75940009330206, 64.96437666717893],
+        ]
+    )
+
+    lat = np.array(
+        [
+            [66.63852914622773, 66.57692364510149, 66.51510790697783],
+            [66.72632651121215, 66.66454929137457, 66.60256232699675],
+            [66.81394503895442, 66.75199541041104, 66.68983654206977],
+        ]
+    )
+
+    lon_bounds = np.array(
+        [
+            [
+                [64.03109895962405, 64.23707042152387, 64.44213290724275],
+                [64.19784426308645, 64.40397614495, 64.60919235424163],
+                [64.36578231818473, 64.57206989228206, 64.77743506492257],
+            ],
+            [
+                [64.23707042152385, 64.44213290724275, 64.64629053434521],
+                [64.40397614494998, 64.60919235424163, 64.81349710155956],
+                [64.57206989228204, 64.77743506492257, 64.98188214131258],
+            ],
+            [
+                [64.40397614494998, 64.60919235424161, 64.81349710155956],
+                [64.57206989228204, 64.77743506492257, 64.98188214131258],
+                [64.74136272095073, 64.94687197648351, 65.15145647131322],
+            ],
+            [
+                [64.19784426308645, 64.40397614495, 64.60919235424161],
+                [64.36578231818473, 64.57206989228206, 64.77743506492257],
+                [64.53492430330854, 64.74136272095075, 64.94687197648351],
+            ],
+        ]
+    )
+
+    lat_bounds = np.array(
+        [
+            [
+                [66.62524451217388, 66.56383049714253, 66.50220514181308],
+                [66.71321640554079, 66.65163077691872, 66.58983429068188],
+                [66.801010821918, 66.73925288286632, 66.67728458111449],
+            ],
+            [
+                [66.56383049714253, 66.50220514181308, 66.44037016643905],
+                [66.65163077691872, 66.58983429068188, 66.52782867442114],
+                [66.73925288286632, 66.67728458111449, 66.61510765153199],
+            ],
+            [
+                [66.6516307769187, 66.58983429068185, 66.52782867442114],
+                [66.73925288286632, 66.67728458111449, 66.61510765153199],
+                [66.82669478850752, 66.76455398820585, 66.702205074604],
+            ],
+            [
+                [66.71321640554079, 66.6516307769187, 66.58983429068185],
+                [66.801010821918, 66.73925288286632, 66.67728458111449],
+                [66.88862573342278, 66.82669478850752, 66.76455398820585],
+            ],
+        ]
+    )
+
+    rotated = xr.Dataset(
+        coords=dict(
+            lon=xr.DataArray(
+                lon,
+                dims=("x", "y"),
+                attrs={"units": "degrees_east", "bounds": "lon_bounds"},
+            ),
+            lat=xr.DataArray(
+                lat,
+                dims=("x", "y"),
+                attrs={"units": "degrees_north", "bounds": "lat_bounds"},
+            ),
         ),
-        lat_bounds=xr.DataArray(
-            lat_bounds, dims=("bounds", "x", "y"), attrs={"units": "degrees_north"}
+        data_vars=dict(
+            lon_bounds=xr.DataArray(
+                lon_bounds, dims=("bounds", "x", "y"), attrs={"units": "degrees_east"}
+            ),
+            lat_bounds=xr.DataArray(
+                lat_bounds, dims=("bounds", "x", "y"), attrs={"units": "degrees_north"}
+            ),
         ),
-        lon_vertices=xr.DataArray(lon_vertices, dims=("x_vertices", "y_vertices")),
-        lat_vertices=xr.DataArray(lat_vertices, dims=("x_vertices", "y_vertices")),
-    ),
-)
+    )
+
+    return rotated
+
+
+rotds = _create_inexact_bounds()
+
 
 forecast = xr.decode_cf(
     xr.Dataset.from_dict(
@@ -483,3 +592,12 @@ vert = xr.Dataset.from_dict(
         },
     }
 )
+
+
+dsg = xr.Dataset(
+    {"foo": (("trajectory", "profile"), [[1, 2, 3], [1, 2, 3]])},
+    coords={
+        "profile": ("profile", [0, 1, 2], {"cf_role": "profile_id"}),
+        "trajectory": ("trajectory", [0, 1], {"cf_role": "trajectory_id"}),
+    },
+)
