@@ -7,6 +7,108 @@ import xarray as xr
 from xarray import DataArray
 
 
+def _guess_bounds_1d(da, dim):
+    """
+    Guess bounds values given a 1D coordinate variable.
+    Assumes equal spacing on either side of the coordinate label.
+    This is an approximation only.
+    Output has an added "bounds" dimension at the end.
+    """
+    if dim not in da.dims:
+        (dim,) = da.cf.axes[dim]
+    ADDED_INDEX = False
+    if dim not in da.coords:
+        # For proper alignment in the lines below, we need an index on dim.
+        da = da.assign_coords({dim: da[dim]})
+        ADDED_INDEX = True
+
+    diff = da.diff(dim)
+    lower = da - diff / 2
+    upper = da + diff / 2
+    bounds = xr.concat([lower, upper], dim="bounds")
+
+    first = (bounds.isel({dim: 0}) - diff.isel({dim: 0})).assign_coords(
+        {dim: da[dim][0]}
+    )
+    result = xr.concat([first, bounds], dim=dim).transpose(..., "bounds")
+    if ADDED_INDEX:
+        result = result.drop_vars(dim)
+    return result
+
+
+def _guess_bounds_2d(da, dims):
+    """
+    Guess bounds values given a 2D coordinate variable.
+    Assumes equal spacing on either side of the coordinate label.
+    This is a coarse approximation, especially for curvilinear grids.
+    Output has an added "bounds" dimension at the end.
+    """
+    daX = _guess_bounds_1d(da, dims[0]).rename(bounds="Xbnds")
+    daXY = _guess_bounds_1d(daX, dims[1]).rename(bounds="Ybnds")
+    # At this point, we might have different corners for adjacent cells, we average them together to have a nice grid
+    # To make this vectorized and keep the edges, we'll pad with NaNs and ignore them in the averages
+    daXYp = (
+        daXY.pad({d: (1, 1) for d in dims}, mode="constant", constant_values=np.NaN)
+        .transpose(*dims, "Xbnds", "Ybnds")
+        .values
+    )  # Tranpose for an easier notation
+    # Mean of the corners that should be the same point.
+    daXYm = np.stack(
+        (
+            # Lower left corner (mean of : upper right of the lower left cell, lower right of the upper left cell, and so on, ccw)
+            np.nanmean(
+                np.stack(
+                    (
+                        daXYp[:-2, :-2, 1, 1],
+                        daXYp[:-2, 1:-1, 1, 0],
+                        daXYp[1:-1, 1:-1, 0, 0],
+                        daXYp[1:-1, :-2, 0, 1],
+                    )
+                ),
+                axis=0,
+            ),
+            # Upper left corner
+            np.nanmean(
+                np.stack(
+                    (
+                        daXYp[:-2, 1:-1, 1, 1],
+                        daXYp[:-2, 2:, 1, 0],
+                        daXYp[1:-1, 2:, 0, 0],
+                        daXYp[1:-1, 1:-1, 0, 1],
+                    )
+                ),
+                axis=0,
+            ),
+            # Upper right
+            np.nanmean(
+                np.stack(
+                    (
+                        daXYp[1:-1, 1:-1, 1, 1],
+                        daXYp[1:-1, 2:, 1, 0],
+                        daXYp[2:, 2:, 0, 0],
+                        daXYp[2:, 1:-1, 0, 1],
+                    )
+                ),
+                axis=0,
+            ),
+            # Lower right
+            np.nanmean(
+                np.stack(
+                    (
+                        daXYp[1:-1, :-2, 1, 1],
+                        daXYp[1:-1, 1:-1, 1, 0],
+                        daXYp[2:, 1:-1, 0, 0],
+                        daXYp[2:, :-2, 0, 1],
+                    )
+                ),
+                axis=0,
+            ),
+        ),
+        axis=-1,
+    )
+    return xr.DataArray(daXYm, dims=(*dims, "bounds"), coords=da.coords)
+
+
 def bounds_to_vertices(
     bounds: DataArray,
     bounds_dim: str,
